(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     50052,       1452]
NotebookOptionsPosition[     46608,       1350]
NotebookOutlinePosition[     46952,       1365]
CellTagsIndexPosition[     46909,       1362]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["1. Results obtained using the asymptotic formula \
(13)", "Section"]], "Text",
 CellChangeTimes->{{3.689591263082793*^9, 3.689591304168793*^9}}],

Cell[TextData[{
 "The following is the code of the Mathematica function implementing the \
asymptotic formula (13) of Dimitrova et al. (2016). Since there are infinite \
summations in the asymptotic formula, we have truncated the summations from \
-20 to +20. To obtain the probability values in Table 1, we modify the line \
\[OpenCurlyDoubleQuote]",
 StyleBox["lambda = 1", "Input"],
 "\[CloseCurlyDoubleQuote] below to the corresponding values of \
\[OpenCurlyDoubleQuote]",
 StyleBox["lambda", "Input"],
 "\[CloseCurlyDoubleQuote].\n\nNote that when \[OpenCurlyDoubleQuote]",
 StyleBox["lambda = 3", "Input"],
 "\[CloseCurlyDoubleQuote], the probability is close to zero. Hence, we will \
need to increase the working precision and the precision goal, for example, \
by inputting \[OpenCurlyDoubleQuote]",
 StyleBox["WorkingPrecision -> 30, PrecisionGoal -> 20", "Input"],
 "\[CloseCurlyDoubleQuote] into the function \[OpenCurlyDoubleQuote]",
 StyleBox["NIntegrate[]", "Input"],
 "\[CloseCurlyDoubleQuote]."
}], "Text",
 CellChangeTimes->{{3.6895914550877934`*^9, 3.6895915046847935`*^9}, {
  3.689591544122793*^9, 3.6895915656017933`*^9}, {3.6895917334567933`*^9, 
  3.6895918019487934`*^9}, {3.6895918374937935`*^9, 3.689592132899793*^9}}],

Cell[BoxData[""], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "[", "l_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", "l", ")"}]}], " ", "*", " ", 
   RowBox[{"1", " ", "/", " ", 
    RowBox[{"(", 
     RowBox[{"2", " ", "*", " ", "Pi"}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"f2", " ", "-", " ", "f1"}], ")"}], " ", "*", " ", 
      RowBox[{"(", 
       RowBox[{"f3", " ", "-", " ", "f2"}], ")"}], "*", "  ", 
      RowBox[{"(", 
       RowBox[{"f4", " ", "-", " ", "f3"}], ")"}]}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"f1", " ", "=", " ", "0"}], "\[IndentingNewLine]", 
 RowBox[{"f2", " ", "=", " ", 
  RowBox[{"1", "/", "2"}]}], "\[IndentingNewLine]", 
 RowBox[{"f3", " ", "=", " ", 
  RowBox[{"4", "/", "5"}]}], "\[IndentingNewLine]", 
 RowBox[{"f4", " ", "=", " ", "1"}], "\[IndentingNewLine]", 
 RowBox[{"lambda", " ", "=", " ", "1"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "l_"}], "]"}], ":=", 
  RowBox[{"Exp", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}], " ", "*", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"x1", "^", 
         RowBox[{"(", "2", ")"}]}], "/", 
        RowBox[{"(", 
         RowBox[{"f2", " ", "-", " ", "f1"}], ")"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"x2", "^", 
         RowBox[{"(", "2", ")"}]}], "/", 
        RowBox[{"(", 
         RowBox[{"f4", " ", "-", " ", "f3"}], ")"}]}]}], ")"}]}], " ", "-", 
    " ", 
    RowBox[{
     RowBox[{"1", "/", "2"}], " ", "*", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x2", " ", "-", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "^", 
           RowBox[{"(", "l", ")"}]}], " ", "*", " ", "x1"}], "-", 
         RowBox[{"2", " ", "*", " ", "lambda", " ", "*", " ", "l"}]}], ")"}], 
       "^", 
       RowBox[{"(", "2", ")"}]}], "/", 
      RowBox[{"(", 
       RowBox[{"f3", " ", "-", " ", "f2"}], ")"}]}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"For", " ", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sum", " ", "=", " ", "0"}], ";", " ", 
      RowBox[{"i", " ", "=", " ", 
       RowBox[{"-", "20"}]}]}], ",", " ", 
     RowBox[{"i", " ", "\[LessEqual]", " ", "20"}], ",", " ", 
     RowBox[{"i", "++"}], ",", " ", 
     RowBox[{"sum", " ", "+=", " ", 
      RowBox[{
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{"g", "[", 
          RowBox[{"x1", ",", "x2", ",", "i"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x1", ",", " ", 
           RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x2", ",", 
           RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}]}], "]"}], "*", 
       RowBox[{"f", "[", "i", "]"}]}]}]}], "]"}], " ", ";", 
   RowBox[{"1", " ", "-", " ", "sum"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.6895910720497932`*^9}],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{3.689591072050793*^9}],

Cell[BoxData[
 FractionBox["4", "5"]], "Output",
 CellChangeTimes->{3.689591072051793*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.6895910720527935`*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.6895910720547934`*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","izero",
   "\"Integral and error estimates are 0 on all integration subregions. Try \
increasing the value of the MinRecursion option. If value of integral may be \
0, specify a finite value for the AccuracyGoal option.\"",2,128,41,
   19916134781599832779,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.6895910720557933`*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","izero",
   "\"Integral and error estimates are 0 on all integration subregions. Try \
increasing the value of the MinRecursion option. If value of integral may be \
0, specify a finite value for the AccuracyGoal option.\"",2,128,42,
   19916134781599832779,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.689591072072793*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","izero",
   "\"Integral and error estimates are 0 on all integration subregions. Try \
increasing the value of the MinRecursion option. If value of integral may be \
0, specify a finite value for the AccuracyGoal option.\"",2,128,43,
   19916134781599832779,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.6895910720887933`*^9}],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"NIntegrate\\\", \
\\\"::\\\", \\\"izero\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,128,44,19916134781599832779,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.6895910721047935`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.4836031`", ",", "0.17452523760991345`"}], "}"}]], "Output",
 CellChangeTimes->{3.6895910725427933`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f", "[", "l_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"(", "l", ")"}]}], " ", "*", " ", 
   RowBox[{"1", " ", "/", " ", 
    RowBox[{"(", 
     RowBox[{"2", " ", "*", " ", "Pi"}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"f2", " ", "-", " ", "f1"}], ")"}], " ", "*", " ", 
      RowBox[{"(", 
       RowBox[{"f3", " ", "-", " ", "f2"}], ")"}], "*", "  ", 
      RowBox[{"(", 
       RowBox[{"f4", " ", "-", " ", "f3"}], ")"}]}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"f1", " ", "=", " ", "0"}], "\[IndentingNewLine]", 
 RowBox[{"f2", " ", "=", " ", 
  RowBox[{"1", "/", "2"}]}], "\[IndentingNewLine]", 
 RowBox[{"f3", " ", "=", " ", 
  RowBox[{"4", "/", "5"}]}], "\[IndentingNewLine]", 
 RowBox[{"f4", " ", "=", " ", "1"}], "\[IndentingNewLine]", 
 RowBox[{"lambda", " ", "=", " ", "3"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{"x1_", ",", "x2_", ",", "l_"}], "]"}], ":=", 
  RowBox[{"Exp", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}], " ", "*", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"x1", "^", 
         RowBox[{"(", "2", ")"}]}], "/", 
        RowBox[{"(", 
         RowBox[{"f2", " ", "-", " ", "f1"}], ")"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"x2", "^", 
         RowBox[{"(", "2", ")"}]}], "/", 
        RowBox[{"(", 
         RowBox[{"f4", " ", "-", " ", "f3"}], ")"}]}]}], ")"}]}], " ", "-", 
    " ", 
    RowBox[{
     RowBox[{"1", "/", "2"}], " ", "*", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x2", " ", "-", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "^", 
           RowBox[{"(", "l", ")"}]}], " ", "*", " ", "x1"}], "-", 
         RowBox[{"2", " ", "*", " ", "lambda", " ", "*", " ", "l"}]}], ")"}], 
       "^", 
       RowBox[{"(", "2", ")"}]}], "/", 
      RowBox[{"(", 
       RowBox[{"f3", " ", "-", " ", "f2"}], ")"}]}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"For", " ", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sum", " ", "=", " ", "0"}], ";", " ", 
      RowBox[{"i", " ", "=", " ", 
       RowBox[{"-", "20"}]}]}], ",", " ", 
     RowBox[{"i", " ", "\[LessEqual]", " ", "20"}], ",", " ", 
     RowBox[{"i", "++"}], ",", " ", 
     RowBox[{"sum", " ", "+=", " ", 
      RowBox[{
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{"g", "[", 
          RowBox[{"x1", ",", "x2", ",", "i"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x1", ",", " ", 
           RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x2", ",", 
           RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", "  ", 
         StyleBox[
          RowBox[{"WorkingPrecision", " ", "->", " ", "30"}], "Input"], 
         StyleBox[",", "Input"], 
         StyleBox[" ", "Input"], 
         StyleBox[
          RowBox[{"PrecisionGoal", " ", "->", " ", "20"}], "Input"]}], "]"}], 
       "*", 
       RowBox[{"f", "[", "i", "]"}]}]}]}], "]"}], " ", ";", 
   RowBox[{"1", " ", "-", " ", "sum"}]}], " ", 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6895941913127933`*^9, 3.689594265888793*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.689594233263793*^9, 3.6895942667107935`*^9}}],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{{3.689594233263793*^9, 3.6895942667137933`*^9}}],

Cell[BoxData[
 FractionBox["4", "5"]], "Output",
 CellChangeTimes->{{3.689594233263793*^9, 3.689594266716793*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.689594233263793*^9, 3.689594266718793*^9}}],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{{3.689594233263793*^9, 3.6895942667207932`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","slwcon",
   "\"Numerical integration converging too slowly; suspect one of the \
following: singularity, value of the integration is 0, highly oscillatory \
integrand, or WorkingPrecision too small.\"",2,232,69,19916134781599832779,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.689594233379793*^9, 3.6895942695547934`*^9}}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","eincr",
   "\"The global error of the strategy GlobalAdaptive has increased more than \
\\!\\(\\*RowBox[{\\\"2000\\\"}]\\) times. The global error is expected to \
decrease monotonically after a number of integrand evaluations. Suspect one \
of the following: the working precision is insufficient for the specified \
precision goal; the integrand is highly oscillatory or it is not a \
(piecewise) smooth function; or the true value of the integral is 0. \
Increasing the value of the GlobalAdaptive option MaxErrorIncreases might \
lead to a convergent numerical integration. NIntegrate obtained \
\\!\\(\\*RowBox[{\\\"2.\
322881247194499512321139041879097120196181362090926296781677825521391464219010\
9`80.*^-9426\\\"}]\\) and \
\\!\\(\\*RowBox[{\\\"5.\
898032113878889851313127490534773218173090258697000472566695104855641847220998\
4`80.*^-9442\\\"}]\\) for the integral and error estimates.\"",2,232,70,
   19916134781599832779,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.689594233379793*^9, 3.689594258862793*^9}, 
   3.6895943530927935`*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","slwcon",
   "\"Numerical integration converging too slowly; suspect one of the \
following: singularity, value of the integration is 0, highly oscillatory \
integrand, or WorkingPrecision too small.\"",2,232,71,19916134781599832779,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.689594233379793*^9, 3.689594258862793*^9}, 
   3.6895943553717933`*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","eincr",
   "\"The global error of the strategy GlobalAdaptive has increased more than \
\\!\\(\\*RowBox[{\\\"2000\\\"}]\\) times. The global error is expected to \
decrease monotonically after a number of integrand evaluations. Suspect one \
of the following: the working precision is insufficient for the specified \
precision goal; the integrand is highly oscillatory or it is not a \
(piecewise) smooth function; or the true value of the integral is 0. \
Increasing the value of the GlobalAdaptive option MaxErrorIncreases might \
lead to a convergent numerical integration. NIntegrate obtained \
\\!\\(\\*RowBox[{\\\"3.\
532746959379771204985134033754770652087969669372647408336077252976824513847665\
9`80.*^-8462\\\"}]\\) and \
\\!\\(\\*RowBox[{\\\"9.\
076558054773606275575853366744652619410672400454803168482562210244539524857688\
5`80.*^-8478\\\"}]\\) for the integral and error estimates.\"",2,232,72,
   19916134781599832779,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.689594233379793*^9, 3.689594258862793*^9}, 
   3.6895944337787933`*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","slwcon",
   "\"Numerical integration converging too slowly; suspect one of the \
following: singularity, value of the integration is 0, highly oscillatory \
integrand, or WorkingPrecision too small.\"",2,232,73,19916134781599832779,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.689594233379793*^9, 3.689594258862793*^9}, 
   3.689594435471793*^9}],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"NIntegrate\\\", \
\\\"::\\\", \\\"slwcon\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,232,74,19916134781599832779,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.689594233379793*^9, 3.689594258862793*^9}, 
   3.689594435487793*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","eincr",
   "\"The global error of the strategy GlobalAdaptive has increased more than \
\\!\\(\\*RowBox[{\\\"2000\\\"}]\\) times. The global error is expected to \
decrease monotonically after a number of integrand evaluations. Suspect one \
of the following: the working precision is insufficient for the specified \
precision goal; the integrand is highly oscillatory or it is not a \
(piecewise) smooth function; or the true value of the integral is 0. \
Increasing the value of the GlobalAdaptive option MaxErrorIncreases might \
lead to a convergent numerical integration. NIntegrate obtained \
\\!\\(\\*RowBox[{\\\"4.\
146765149935119865970049798519232557568584911165476468806487845915411399424177\
8`80.*^-7550\\\"}]\\) and \
\\!\\(\\*RowBox[{\\\"1.\
053456078283626418203672686814257720025528687801373569119060186153138865026987\
9`80.*^-7565\\\"}]\\) for the integral and error estimates.\"",2,232,75,
   19916134781599832779,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.689594233379793*^9, 3.689594258862793*^9}, 
   3.6895945202907934`*^9}],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"NIntegrate\\\", \
\\\"::\\\", \\\"eincr\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,232,76,19916134781599832779,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.689594233379793*^9, 3.689594258862793*^9}, 
   3.6895945208237934`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3142.8897466`", ",", 
   "1.72031153187538652595843599975173546798081925280306`22.23560709482656*^-\
8"}], "}"}]], "Output",
 CellChangeTimes->{{3.689594233263793*^9, 3.689594258840793*^9}, 
   3.689597426952793*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["     2. Results obtained using the asymptotic formula (20)", "Section",
 CellChangeTimes->{{3.689592366596793*^9, 3.689592400282793*^9}}],

Cell["\<\
The following is the code of the Mathematica function implementing the \
asymptotic formula (20) of Dimitrova et al. (2016).\
\>", "Text",
 CellChangeTimes->{{3.6895924780717936`*^9, 3.6895924850787935`*^9}}],

Cell[CellGroupData[{

Cell["2.1 When F(x) follows a Binomial(3, 0.5) distribution", "Subsection",
 CellChangeTimes->{{3.689592529428793*^9, 3.689592572072793*^9}}],

Cell[TextData[{
 "To obtain the probability values in Table 3, we modify the line \
\[OpenCurlyDoubleQuote]",
 StyleBox["lambda = 1", "Input"],
 "\[CloseCurlyDoubleQuote] below to the corresponding values of \
\[OpenCurlyDoubleQuote]",
 StyleBox["lambda", "Input"],
 "\[CloseCurlyDoubleQuote]."
}], "Text",
 CellChangeTimes->{
  3.689592617041793*^9, {3.689597868727793*^9, 3.6895978699107933`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"0", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "-", "0"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "3"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"1", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "-", "1"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "3"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "-", "2"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "3"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a4", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "-", "3"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "3"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"lambda", "=", "1"}], "\[IndentingNewLine]", 
 RowBox[{"c", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "*", "Pi"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "4"}], ")"}], "/", "2"}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a1", "*", "a2", "*", "a3", "*", "a4"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"x1_", ",", " ", "x2_", ",", " ", "x3_"}], "]"}], ":=", " ", 
  RowBox[{"Exp", "[", 
   RowBox[{
    RowBox[{"-", "0.5"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"x1", "^", "2"}], "/", "a1"}], " ", "+", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x2", "-", "x1"}], ")"}], "^", "2"}], "/", "a2"}], " ", "+", 
      " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x3", "-", "x2"}], ")"}], "^", "2"}], "/", "a3"}], " ", "+", 
      " ", 
      RowBox[{
       RowBox[{"x3", "^", "2"}], "/", "a4"}]}], "  ", ")"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"1", "-", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"c", "*", 
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"f", "[", 
         RowBox[{"x1", ",", "x2", ",", "x3"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x1", ",", 
          RowBox[{"-", "lambda"}], ",", " ", "lambda"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x2", ",", 
          RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x3", ",", 
          RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}]}], "]"}]}], ",", 
     " ", "16"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6895911074377933`*^9, 3.6895911075497932`*^9}}],

Cell[BoxData[
 FractionBox["1", "8"]], "Output",
 CellChangeTimes->{3.689591114994793*^9}],

Cell[BoxData[
 FractionBox["3", "8"]], "Output",
 CellChangeTimes->{3.6895911149967933`*^9}],

Cell[BoxData[
 FractionBox["3", "8"]], "Output",
 CellChangeTimes->{3.689591114997793*^9}],

Cell[BoxData[
 FractionBox["1", "8"]], "Output",
 CellChangeTimes->{3.689591114999793*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.6895911150007935`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"16", " ", 
   SqrtBox["2"]}], 
  RowBox[{"3", " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{3.6895911150027933`*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","precw",
   "\"The precision of the argument function \
(\\!\\(\\*RowBox[{SuperscriptBox[\\\"\[ExponentialE]\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"1.9999999999999998`\\\"}], \\\" \\\", \
SuperscriptBox[\\\"x2\\\", \\\"2\\\"]}]], \\\" \\\", RowBox[{\\\"(\\\", \
RowBox[{RowBox[{\\\"0.14726215563702155`\\\", \\\" \\\", RowBox[{\\\"Erf\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"(\\\", \
RowBox[{RowBox[{\\\"2.309401076758503`\\\", \\\"\[VeryThinSpace]\\\"}], \\\"+\
\\\", RowBox[{\\\"0.`\\\", \\\" \\\", \\\"\[ImaginaryI]\\\"}]}], \\\")\\\"}], \
\\\"-\\\", RowBox[{RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"0.5773502691896257`\
\\\", \\\"\[VeryThinSpace]\\\"}], \\\"+\\\", RowBox[{\\\"0.`\\\", \\\" \\\", \
\\\"\[ImaginaryI]\\\"}]}], \\\")\\\"}], \\\" \\\", \\\"x2\\\"}]}], \
\\\"]\\\"}]}], \\\"+\\\", RowBox[{\\\"0.14726215563702155`\\\", \\\" \\\", \
RowBox[{\\\"Erf\\\", \\\"[\\\", RowBox[{RowBox[{\\\"2.309401076758503`\\\", \
\\\"\[VeryThinSpace]\\\"}], \\\"+\\\", RowBox[{\\\"0.5773502691896257`\\\", \
\\\" \\\", \\\"x2\\\"}]}], \\\"]\\\"}]}]}], \\\")\\\"}], \\\" \\\", \
RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"Erf\\\", \\\"[\\\", RowBox[{RowBox[{\\\
\"2.309401076758503`\\\", \\\"\[VeryThinSpace]\\\"}], \\\"-\\\", \
RowBox[{\\\"0.5773502691896257`\\\", \\\" \\\", \\\"x2\\\"}]}], \\\"]\\\"}], \
\\\"+\\\", RowBox[{\\\"Erf\\\", \\\"[\\\", \
RowBox[{RowBox[{\\\"2.309401076758503`\\\", \\\"\[VeryThinSpace]\\\"}], \\\"+\
\\\", RowBox[{\\\"0.5773502691896257`\\\", \\\" \\\", \\\"x2\\\"}]}], \\\"]\\\
\"}]}], \\\")\\\"}]}]\\)) is less than WorkingPrecision \
(\\!\\(\\*RowBox[{\\\"26.`\\\"}]\\)).\"",2,136,45,19916134781599832779,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.689591128010793*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "12.9012827`", ",", 
   "0.04943858229819389625348473005265665545`14.238964570932007"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.689591128057793*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2 When F(x) follows a Binomial(7, 0.5) distribution ", "Subsection",
 CellChangeTimes->{{3.6895926852987933`*^9, 3.6895926856187935`*^9}, {
  3.689592716944793*^9, 3.689592749630793*^9}}],

Cell[TextData[{
 "To obtain the probability values in Table 4, we modify the line \
\[OpenCurlyDoubleQuote]",
 StyleBox["lambda = 1", "Input"],
 "\[CloseCurlyDoubleQuote] below to the corresponding values of \
\[OpenCurlyDoubleQuote]",
 StyleBox["lambda", "Input"],
 "\[CloseCurlyDoubleQuote].\n\nNote that when \[OpenCurlyDoubleQuote]",
 StyleBox["lambda = 3", "Input"],
 "\[CloseCurlyDoubleQuote], the probability is close to zero. Hence, we will \
need to increase the working precision and the precision goal, for example, \
by inputting \[OpenCurlyDoubleQuote]",
 StyleBox["WorkingPrecision -> 100, PrecisionGoal -> 40", "Input"],
 "\[CloseCurlyDoubleQuote] into the function \[OpenCurlyDoubleQuote]",
 StyleBox["NIntegrate[]", "Input"],
 "\[CloseCurlyDoubleQuote]."
}], "Text",
 CellChangeTimes->{
  3.689592764630793*^9, {3.689594125513793*^9, 3.6895941467527933`*^9}, {
   3.6895978835597935`*^9, 3.689597884079793*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"0", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "0"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"1", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "1"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "2"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a4", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "3"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a5", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "4"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a6", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"5", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "5"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a7", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "6"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a8", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"7", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "7"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"lambda", "=", "1"}], "\[IndentingNewLine]", 
 RowBox[{"c", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "*", "Pi"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "8"}], ")"}], "/", "2"}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
     "a1", "*", "a2", "*", "a3", "*", "a4", "*", "a5", "*", "a6", "*", "a7", 
      "*", "a8"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{
   "x1_", ",", " ", "x2_", ",", " ", "x3_", ",", "x4_", ",", "x5_", ",", 
    "x6_", ",", "x7_"}], "]"}], ":=", " ", 
  RowBox[{"Exp", "[", 
   RowBox[{
    RowBox[{"-", "0.5"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"x1", "^", "2"}], "/", "a1"}], " ", "+", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x2", "-", "x1"}], ")"}], "^", "2"}], "/", "a2"}], " ", "+", 
      " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x3", "-", "x2"}], ")"}], "^", "2"}], "/", "a3"}], " ", "+", 
      " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x4", "-", "x3"}], ")"}], "^", "2"}], "/", "a4"}], "+", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x5", "-", "x4"}], ")"}], "^", "2"}], "/", "a5"}], " ", "+", 
      " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x6", "-", "x5"}], ")"}], "^", "2"}], "/", "a6"}], " ", "+", 
      " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x7", "-", "x6"}], ")"}], "^", "2"}], "/", "a7"}], " ", "+", 
      RowBox[{
       RowBox[{"x7", "^", "2"}], "/", "a8"}]}], ")"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"1", "-", 
   RowBox[{"c", "*", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5", ",", "x6", ",", 
        "x7"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x1", ",", 
        RowBox[{"-", "lambda"}], ",", " ", "lambda"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2", ",", 
        RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x3", ",", 
        RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x4", ",", 
        RowBox[{"-", "lambda"}], ",", " ", "lambda"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x5", ",", 
        RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x6", ",", 
        RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x7", ",", 
        RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}]}], "]"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.689594297556793*^9, 3.6895943357577934`*^9}}],

Cell[BoxData[
 FractionBox["1", "128"]], "Output",
 CellChangeTimes->{3.6895977920687933`*^9}],

Cell[BoxData[
 FractionBox["7", "128"]], "Output",
 CellChangeTimes->{3.6895977920717936`*^9}],

Cell[BoxData[
 FractionBox["21", "128"]], "Output",
 CellChangeTimes->{3.6895977920737934`*^9}],

Cell[BoxData[
 FractionBox["35", "128"]], "Output",
 CellChangeTimes->{3.6895977920757933`*^9}],

Cell[BoxData[
 FractionBox["35", "128"]], "Output",
 CellChangeTimes->{3.689597792076793*^9}],

Cell[BoxData[
 FractionBox["21", "128"]], "Output",
 CellChangeTimes->{3.689597792077793*^9}],

Cell[BoxData[
 FractionBox["7", "128"]], "Output",
 CellChangeTimes->{3.689597792079793*^9}],

Cell[BoxData[
 FractionBox["1", "128"]], "Output",
 CellChangeTimes->{3.6895977920807934`*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.6895977920817933`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"16777216", " ", 
   SqrtBox["2"]}], 
  RowBox[{"5145", " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"7", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{3.689597792082793*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","slwcon",
   "\"Numerical integration converging too slowly; suspect one of the \
following: singularity, value of the integration is 0, highly oscillatory \
integrand, or WorkingPrecision too small.\"",2,244,77,19916134781599832779,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.689597796741793*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","eincr",
   "\"The global error of the strategy GlobalAdaptive has increased more than \
\\!\\(\\*RowBox[{\\\"2000\\\"}]\\) times. The global error is expected to \
decrease monotonically after a number of integrand evaluations. Suspect one \
of the following: the working precision is insufficient for the specified \
precision goal; the integrand is highly oscillatory or it is not a \
(piecewise) smooth function; or the true value of the integral is 0. \
Increasing the value of the GlobalAdaptive option MaxErrorIncreases might \
lead to a convergent numerical integration. NIntegrate obtained \
\\!\\(\\*RowBox[{\\\"0.011081091188939352`\\\"}]\\) and \
\\!\\(\\*RowBox[{\\\"0.000045633530625087884`\\\"}]\\) for the integral and \
error estimates.\"",2,244,78,19916134781599832779,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.689597814725793*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"22.5733447`", ",", "0.07016157526995004`"}], "}"}]], "Output",
 CellChangeTimes->{3.6895978147267933`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.689594297556793*^9, 3.689594313412793*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"0", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "0"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"1", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "1"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "2"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a4", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "3"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a5", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "4"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a6", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"5", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "5"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a7", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "6"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"a8", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "!"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"7", "!"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"7", "-", "7"}], ")"}], "!"}]}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], "^", "7"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"lambda", "=", "3"}], "\[IndentingNewLine]", 
 RowBox[{"c", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "*", "Pi"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "8"}], ")"}], "/", "2"}], ")"}]}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
     "a1", "*", "a2", "*", "a3", "*", "a4", "*", "a5", "*", "a6", "*", "a7", 
      "*", "a8"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}], ")"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{
   "x1_", ",", " ", "x2_", ",", " ", "x3_", ",", "x4_", ",", "x5_", ",", 
    "x6_", ",", "x7_"}], "]"}], ":=", " ", 
  RowBox[{"Exp", "[", 
   RowBox[{
    RowBox[{"-", "0.5"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"x1", "^", "2"}], "/", "a1"}], " ", "+", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x2", "-", "x1"}], ")"}], "^", "2"}], "/", "a2"}], " ", "+", 
      " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x3", "-", "x2"}], ")"}], "^", "2"}], "/", "a3"}], " ", "+", 
      " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x4", "-", "x3"}], ")"}], "^", "2"}], "/", "a4"}], "+", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x5", "-", "x4"}], ")"}], "^", "2"}], "/", "a5"}], " ", "+", 
      " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x6", "-", "x5"}], ")"}], "^", "2"}], "/", "a6"}], " ", "+", 
      " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x7", "-", "x6"}], ")"}], "^", "2"}], "/", "a7"}], " ", "+", 
      RowBox[{
       RowBox[{"x7", "^", "2"}], "/", "a8"}]}], ")"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"1", "-", 
   RowBox[{"c", "*", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{
       "x1", ",", "x2", ",", "x3", ",", "x4", ",", "x5", ",", "x6", ",", 
        "x7"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x1", ",", 
        RowBox[{"-", "lambda"}], ",", " ", "lambda"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2", ",", 
        RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x3", ",", 
        RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x4", ",", 
        RowBox[{"-", "lambda"}], ",", " ", "lambda"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x5", ",", 
        RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x6", ",", 
        RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x7", ",", 
        RowBox[{"-", "lambda"}], ",", "lambda"}], "}"}], ",", " ", 
      RowBox[{"WorkingPrecision", "\[Rule]", "100"}], ",", " ", 
      StyleBox[
       RowBox[{"PrecisionGoal", " ", "->", " ", "40"}], "Input"]}], "]"}]}]}],
   "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6895914197507935`*^9, 3.689591420411793*^9}, {
  3.689592305400793*^9, 3.689592309994793*^9}, {3.689592707819793*^9, 
  3.689592709084793*^9}, {3.6895929227997932`*^9, 3.6895929230007935`*^9}, {
  3.689593218567793*^9, 3.6895932190147934`*^9}, {3.689594329807793*^9, 
  3.689594330270793*^9}}],

Cell[BoxData[
 FractionBox["1", "128"]], "Output",
 CellChangeTimes->{3.6895911587367935`*^9, 3.689591421466793*^9, 
  3.689592310399793*^9, 3.6895927097537932`*^9, 3.6895929236877933`*^9, 
  3.689593220098793*^9}],

Cell[BoxData[
 FractionBox["7", "128"]], "Output",
 CellChangeTimes->{3.6895911587367935`*^9, 3.689591421466793*^9, 
  3.689592310399793*^9, 3.6895927097537932`*^9, 3.6895929236877933`*^9, 
  3.6895932201017933`*^9}],

Cell[BoxData[
 FractionBox["21", "128"]], "Output",
 CellChangeTimes->{3.6895911587367935`*^9, 3.689591421466793*^9, 
  3.689592310399793*^9, 3.6895927097537932`*^9, 3.6895929236877933`*^9, 
  3.689593220103793*^9}],

Cell[BoxData[
 FractionBox["35", "128"]], "Output",
 CellChangeTimes->{3.6895911587367935`*^9, 3.689591421466793*^9, 
  3.689592310399793*^9, 3.6895927097537932`*^9, 3.6895929236877933`*^9, 
  3.6895932201047935`*^9}],

Cell[BoxData[
 FractionBox["35", "128"]], "Output",
 CellChangeTimes->{3.6895911587367935`*^9, 3.689591421466793*^9, 
  3.689592310399793*^9, 3.6895927097537932`*^9, 3.6895929236877933`*^9, 
  3.6895932201067934`*^9}],

Cell[BoxData[
 FractionBox["21", "128"]], "Output",
 CellChangeTimes->{3.6895911587367935`*^9, 3.689591421466793*^9, 
  3.689592310399793*^9, 3.6895927097537932`*^9, 3.6895929236877933`*^9, 
  3.6895932201087933`*^9}],

Cell[BoxData[
 FractionBox["7", "128"]], "Output",
 CellChangeTimes->{3.6895911587367935`*^9, 3.689591421466793*^9, 
  3.689592310399793*^9, 3.6895927097537932`*^9, 3.6895929236877933`*^9, 
  3.689593220110793*^9}],

Cell[BoxData[
 FractionBox["1", "128"]], "Output",
 CellChangeTimes->{3.6895911587367935`*^9, 3.689591421466793*^9, 
  3.689592310399793*^9, 3.6895927097537932`*^9, 3.6895929236877933`*^9, 
  3.6895932201137934`*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.6895911587367935`*^9, 3.689591421466793*^9, 
  3.689592310399793*^9, 3.6895927097537932`*^9, 3.6895929236877933`*^9, 
  3.689593220115793*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"16777216", " ", 
   SqrtBox["2"]}], 
  RowBox[{"5145", " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"7", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{3.6895911587367935`*^9, 3.689591421466793*^9, 
  3.689592310399793*^9, 3.6895927097537932`*^9, 3.6895929236877933`*^9, 
  3.689593220117793*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","precw",
   "\"The precision of the argument function (\\!\\(\\*SuperscriptBox[\\\"\
\[ExponentialE]\\\", RowBox[{RowBox[{\\\"-\\\", \\\"0.5`\\\"}], \\\" \\\", \
RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"128\\\", \\\" \\\", \
SuperscriptBox[\\\"x1\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{FractionBox[\\\"128\\\", \\\"7\\\"], \\\" \\\", \
SuperscriptBox[RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"x1\\\"}], \\\
\"+\\\", \\\"x2\\\"}], \\\")\\\"}], \\\"2\\\"]}], \\\"+\\\", \
RowBox[{FractionBox[\\\"128\\\", \\\"21\\\"], \\\" \\\", \
SuperscriptBox[RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"x2\\\"}], \\\
\"+\\\", \\\"x3\\\"}], \\\")\\\"}], \\\"2\\\"]}], \\\"+\\\", \
RowBox[{FractionBox[\\\"128\\\", \\\"35\\\"], \\\" \\\", \
SuperscriptBox[RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"x3\\\"}], \\\
\"+\\\", \\\"x4\\\"}], \\\")\\\"}], \\\"2\\\"]}], \\\"+\\\", \
RowBox[{FractionBox[\\\"128\\\", \\\"35\\\"], \\\" \\\", \
SuperscriptBox[RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"x4\\\"}], \\\
\"+\\\", \\\"x5\\\"}], \\\")\\\"}], \\\"2\\\"]}], \\\"+\\\", \
RowBox[{FractionBox[\\\"128\\\", \\\"21\\\"], \\\" \\\", \
SuperscriptBox[RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"x5\\\"}], \\\
\"+\\\", \\\"x6\\\"}], \\\")\\\"}], \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"128\\\", \\\" \\\", SuperscriptBox[\\\"x7\\\", \\\"2\\\"]}], \
\\\"+\\\", RowBox[{FractionBox[\\\"128\\\", \\\"7\\\"], \\\" \\\", \
SuperscriptBox[RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"x6\\\"}], \\\
\"+\\\", \\\"x7\\\"}], \\\")\\\"}], \\\"2\\\"]}]}], \\\")\\\"}]}]]\\)) is \
less than WorkingPrecision (\\!\\(\\*RowBox[{\\\"100.`\\\"}]\\)).\"",2,208,61,
   19916134781599832779,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.689591158754793*^9, 3.6895914214837933`*^9, 
  3.6895923104177933`*^9, 3.6895927097697935`*^9, 3.6895929237067933`*^9, 
  3.6895932201187935`*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","slwcon",
   "\"Numerical integration converging too slowly; suspect one of the \
following: singularity, value of the integration is 0, highly oscillatory \
integrand, or WorkingPrecision too small.\"",2,208,62,19916134781599832779,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.689591158754793*^9, 3.6895914214837933`*^9, 
  3.6895923104177933`*^9, 3.6895927097697935`*^9, 3.6895929237067933`*^9, 
  3.6895932598547935`*^9}],

Cell[BoxData[
 TemplateBox[{
  "NIntegrate","eincr",
   "\"The global error of the strategy GlobalAdaptive has increased more than \
\\!\\(\\*RowBox[{\\\"2000\\\"}]\\) times. The global error is expected to \
decrease monotonically after a number of integrand evaluations. Suspect one \
of the following: the working precision is insufficient for the specified \
precision goal; the integrand is highly oscillatory or it is not a \
(piecewise) smooth function; or the true value of the integral is 0. \
Increasing the value of the GlobalAdaptive option MaxErrorIncreases might \
lead to a convergent numerical integration. NIntegrate obtained \
\\!\\(\\*RowBox[{\\\"0.\
011081010415701793309502769820967455297706066169000596516802606879832916250156\
43906232577410671645353`100.\\\"}]\\) and \
\\!\\(\\*RowBox[{\\\"0.\
000045674073589976926185602458522682807471199760317077612415760170003188456758\
27051413979095168033065044`100.\\\"}]\\) for the integral and error \
estimates.\"",2,208,63,19916134781599832779,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.689591158754793*^9, 3.6895914214837933`*^9, 
  3.6895923104177933`*^9, 3.6895927097697935`*^9, 3.6895929237067933`*^9, 
  3.6895934108787932`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "189.9936179`", ",", 
   "0.070168353127716243940783849533930622608146754002184704833294170259982346\
4588529110855229833985614724243271180323653`98.87773696029105"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.6895911587367935`*^9, 3.689591421466793*^9, 
  3.689592310399793*^9, 3.6895927097537932`*^9, 3.6895929236877933`*^9, 
  3.689593410945793*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1488, 693},
WindowMargins->{{101, Automatic}, {Automatic, 39}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 168, 2, 53, "Text"],
Cell[729, 24, 1246, 22, 106, "Text"],
Cell[1978, 48, 26, 0, 30, "Input"],
Cell[CellGroupData[{
Cell[2029, 52, 3152, 92, 183, "Input"],
Cell[5184, 146, 72, 1, 30, "Output"],
Cell[5259, 149, 90, 2, 46, "Output"],
Cell[5352, 153, 90, 2, 46, "Output"],
Cell[5445, 157, 72, 1, 30, "Output"],
Cell[5520, 160, 72, 1, 30, "Output"],
Cell[5595, 163, 396, 8, 21, "Message"],
Cell[5994, 173, 394, 8, 21, "Message"],
Cell[6391, 183, 396, 8, 21, "Message"],
Cell[6790, 193, 347, 7, 21, "Message"],
Cell[7140, 202, 145, 3, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7322, 210, 3493, 100, 202, "Input"],
Cell[10818, 312, 96, 1, 30, "Output"],
Cell[10917, 315, 116, 2, 46, "Output"],
Cell[11036, 319, 114, 2, 46, "Output"],
Cell[11153, 323, 94, 1, 30, "Output"],
Cell[11250, 326, 96, 1, 30, "Output"],
Cell[11349, 329, 399, 8, 21, "Message"],
Cell[11751, 339, 1124, 20, 73, "Message"],
Cell[12878, 361, 425, 9, 21, "Message"],
Cell[13306, 372, 1124, 20, 73, "Message"],
Cell[14433, 394, 423, 9, 21, "Message"],
Cell[14859, 405, 396, 8, 21, "Message"],
Cell[15258, 415, 1124, 20, 73, "Message"],
Cell[16385, 437, 397, 8, 21, "Message"],
Cell[16785, 447, 259, 7, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17081, 459, 143, 1, 70, "Section"],
Cell[17227, 462, 218, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[17470, 470, 141, 1, 49, "Subsection"],
Cell[17614, 473, 399, 10, 30, "Text"],
Cell[CellGroupData[{
Cell[18038, 487, 3383, 115, 164, "Input"],
Cell[21424, 604, 90, 2, 46, "Output"],
Cell[21517, 608, 92, 2, 46, "Output"],
Cell[21612, 612, 90, 2, 46, "Output"],
Cell[21705, 616, 90, 2, 46, "Output"],
Cell[21798, 620, 72, 1, 30, "Output"],
Cell[21873, 623, 206, 7, 54, "Output"],
Cell[22082, 632, 1767, 28, 28, "Message"],
Cell[23852, 662, 193, 6, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24094, 674, 195, 2, 49, "Subsection"],
Cell[24292, 678, 928, 19, 87, "Text"],
Cell[CellGroupData[{
Cell[25245, 701, 5941, 205, 278, "Input"],
Cell[31189, 908, 94, 2, 46, "Output"],
Cell[31286, 912, 94, 2, 46, "Output"],
Cell[31383, 916, 95, 2, 46, "Output"],
Cell[31481, 920, 95, 2, 46, "Output"],
Cell[31579, 924, 93, 2, 46, "Output"],
Cell[31675, 928, 93, 2, 46, "Output"],
Cell[31771, 932, 92, 2, 46, "Output"],
Cell[31866, 936, 94, 2, 46, "Output"],
Cell[31963, 940, 72, 1, 30, "Output"],
Cell[32038, 943, 213, 7, 54, "Output"],
Cell[32254, 952, 373, 8, 21, "Message"],
Cell[32630, 962, 923, 15, 56, "Message"],
Cell[33556, 979, 146, 3, 30, "Output"]
}, Open  ]],
Cell[33717, 985, 92, 1, 30, "Input"],
Cell[CellGroupData[{
Cell[33834, 990, 6370, 212, 297, "Input"],
Cell[40207, 1204, 214, 4, 46, "Output"],
Cell[40424, 1210, 216, 4, 46, "Output"],
Cell[40643, 1216, 215, 4, 46, "Output"],
Cell[40861, 1222, 217, 4, 46, "Output"],
Cell[41081, 1228, 217, 4, 46, "Output"],
Cell[41301, 1234, 217, 4, 46, "Output"],
Cell[41521, 1240, 214, 4, 46, "Output"],
Cell[41738, 1246, 216, 4, 46, "Output"],
Cell[41957, 1252, 192, 3, 30, "Output"],
Cell[42152, 1257, 335, 9, 54, "Output"],
Cell[42490, 1268, 1945, 31, 33, "Message"],
Cell[44438, 1301, 499, 10, 21, "Message"],
Cell[44940, 1313, 1231, 21, 73, "Message"],
Cell[46174, 1336, 394, 9, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

